@@ -81,8 +81,8 @@ pub enum NeocmakeCli {
         #[arg(value_name = "tojson", short = 'j')]
         tojson: bool,
     },
-    #[command(long_flag = "generate", about = "generate the completion")]
-    GenCompletions {
+    #[command(long_flag = "generate-completion", about = "generate the completion")]
+    GenCompletion {
         // If provided, outputs the completion file for given shell
         #[arg(value_enum, required = true)]
         shell: Shell,
@@ -91,8 +91,9 @@ pub enum NeocmakeCli {
 
 #[test]
 fn test_claps() {
-    use super::NeocmakeCli;
     use clap::{CommandFactory, FromArgMatches};
+
+    use super::NeocmakeCli;
     let mut args =
         NeocmakeCli::command().get_matches_from(vec!["neocmakelsp", "format", "-o", "a", "b"]);
 
