@@ -1,19 +1,11 @@
 mod builtin;
 mod findpackage;
 mod includescanner;
-use crate::consts::TREESITTER_CMAKE_LANGUAGE;
-use crate::fileapi;
-use crate::languageserver::BUFFERS_CACHE;
-use crate::scansubs::TREE_MAP;
-use crate::utils::treehelper::{get_pos_type, PositionType, ToPoint};
-use crate::utils::{
-    gen_module_pattern, include_is_module, remove_quotation_and_replace_placeholders,
-    DocumentNormalize, LineCommentTmp, CACHE_CMAKE_PACKAGES_WITHKEYS,
-};
-use builtin::{BUILTIN_COMMAND, BUILTIN_MODULE, BUILTIN_VARIABLE};
 use std::collections::HashMap;
 use std::path::{Path, PathBuf};
-use std::sync::Arc;
+use std::sync::{Arc, LazyLock};
+
+use builtin::{BUILTIN_COMMAND, BUILTIN_MODULE, BUILTIN_VARIABLE};
 use tokio::fs;
 use tokio::sync::Mutex;
 use tower_lsp::lsp_types::{
@@ -21,9 +13,15 @@ use tower_lsp::lsp_types::{
     Position,
 };
 
-use crate::CMakeNodeKinds;
-
-use std::sync::LazyLock;
+use crate::consts::TREESITTER_CMAKE_LANGUAGE;
+use crate::languageserver::BUFFERS_CACHE;
+use crate::scansubs::TREE_MAP;
+use crate::utils::treehelper::{get_pos_type, PositionType, ToPoint};
+use crate::utils::{
+    gen_module_pattern, include_is_module, remove_quotation_and_replace_placeholders,
+    DocumentNormalize, LineCommentTmp, CACHE_CMAKE_PACKAGES_WITHKEYS,
+};
+use crate::{fileapi, CMakeNodeKinds};
 
 pub type CompleteKV = HashMap<PathBuf, Vec<CompletionItem>>;
 
@@ -35,6 +33,27 @@ pub static COMPLETE_CACHE: LazyLock<Arc<Mutex<CompleteKV>>> =
 #[cfg(unix)]
 const PKG_IMPORT_TARGET: &str = "IMPORTED_TARGET";
 
+pub fn init_builtin_command() {
+    let _ = &*BUILTIN_COMMAND;
+}
+pub fn init_builtin_module() {
+    let _ = &*BUILTIN_MODULE;
+}
+
+pub fn init_builtin_variable() {
+    let _ = &*BUILTIN_VARIABLE;
+}
+
+pub fn init_system_modules() {
+    let _ = &*crate::utils::CMAKE_PACKAGES_WITHKEY;
+    let _ = &*crate::utils::CMAKE_PACKAGES;
+    #[cfg(unix)]
+    {
+        let _ = &*crate::utils::packagepkgconfig::PKG_CONFIG_PACKAGES;
+        let _ = &*crate::utils::packagepkgconfig::PKG_CONFIG_PACKAGES_WITHKEY;
+    }
+}
+
 pub fn rst_doc_read(doc: &str, filename: &str) -> Vec<CompletionItem> {
     doc.lines()
         .filter(|line| line.starts_with(".. command:: "))
@@ -892,6 +911,7 @@ fn comment_mark_test() {
 fn test_complete() {
     use std::fs::File;
     use std::io::Write;
+
     use tempfile::tempdir;
 
     let file_info = r#"
@@ -976,6 +996,7 @@ endfunction()
 fn test_complete_win() {
     use std::fs::File;
     use std::io::Write;
+
     use tempfile::tempdir;
 
     let file_info = "set(AB \"100\")\r\n# test hello \r\nfunction(bb)\r\nendfunction()".normalize();
