@@ -197,57 +197,14 @@ impl LanguageServer for Backend {
             }
         }
 
-        if let Some(ref vcpkg_root) = initial
+        if let Some(ref project_root) = initial
             .workspace_folders
             .as_ref()
             .and_then(|folders| folders.first())
             .and_then(|folder| folder.uri.to_file_path().ok())
         {
-            scansubs::scan_all(&vcpkg_root).await;
             let mut root_path = self.root_path.lock().await;
-            root_path.replace(vcpkg_root.to_path_buf());
-
-            let build_dir = vcpkg_root.join("build");
-
-            if build_dir.is_dir() {
-                if let Some(query) = &*DEFAULT_QUERY {
-                    query.write_to_build_dir(build_dir.as_path()).ok();
-                }
-            }
-            if did_vcpkg_project(vcpkg_root) {
-                tracing::info!("This project is vcpkg project, start init vcpkg data");
-                let project_root = vcpkg_root;
-                let vcpkg_installed_path = project_root.join("vcpkg_installed");
-
-                #[cfg(unix)]
-                {
-                    use crate::utils::packagepkgconfig::QUERYSRULES;
-                    // When it is found to be a vcpkg project, the pc will be searched first from the vcpkg download directory.
-                    QUERYSRULES.lock().unwrap().insert(
-                        0,
-                        Box::leak(
-                            format!("{}/*.pc", vcpkg_installed_path.to_str().unwrap())
-                                .into_boxed_str(),
-                        ),
-                    );
-                }
-
-                // add vcpkg prefix
-                VCPKG_PREFIX.lock().unwrap().push(Box::leak(
-                    vcpkg_installed_path
-                        .to_str()
-                        .unwrap()
-                        .to_string()
-                        .into_boxed_str(),
-                ));
-
-                if let Ok(paths) = utils::make_vcpkg_package_search_path(&vcpkg_installed_path) {
-                    let mut vcpkg_libs = VCPKG_LIBS.lock().unwrap();
-                    for t in paths {
-                        vcpkg_libs.push(Box::leak(t.into_boxed_str()))
-                    }
-                }
-            }
+            root_path.replace(project_root.to_path_buf());
         }
 
         set_client_text_document(initial.capabilities.text_document);
@@ -364,6 +321,84 @@ impl LanguageServer for Backend {
         self.client
             .log_message(MessageType::INFO, "initialized!")
             .await;
+        let root_path_lock = self.root_path.lock().await;
+        let root_path = root_path_lock.clone();
+        drop(root_path_lock);
+        let work_done_token = ProgressToken::Number(1);
+        let progress = self
+            .client
+            .progress(work_done_token, "start initing the workspace")
+            .with_message("initial start")
+            .with_percentage(0)
+            .begin()
+            .await;
+
+        if let Some(ref project_root) = root_path {
+            progress
+                .report_with_message(&format!("start scanning {}", project_root.display()), 10)
+                .await;
+            scansubs::scan_all(&project_root, true).await;
+            let build_dir = project_root.join("build");
+            if build_dir.is_dir() {
+                if let Some(query) = &*DEFAULT_QUERY {
+                    query.write_to_build_dir(build_dir.as_path()).ok();
+                }
+            }
+            if did_vcpkg_project(project_root) {
+                progress
+                    .report_with_message("find vcpkg dir, start scanning", 20)
+                    .await;
+                tracing::info!("This project is vcpkg project, start init vcpkg data");
+                let vcpkg_installed_path = project_root.join("vcpkg_installed");
+
+                #[cfg(unix)]
+                {
+                    use crate::utils::packagepkgconfig::QUERYSRULES;
+                    // When it is found to be a vcpkg project, the pc will be searched first from the vcpkg download directory.
+                    QUERYSRULES.lock().unwrap().insert(
+                        0,
+                        Box::leak(
+                            format!("{}/*.pc", vcpkg_installed_path.to_str().unwrap())
+                                .into_boxed_str(),
+                        ),
+                    );
+                }
+
+                // add vcpkg prefix
+                VCPKG_PREFIX.lock().unwrap().push(Box::leak(
+                    vcpkg_installed_path
+                        .to_str()
+                        .unwrap()
+                        .to_string()
+                        .into_boxed_str(),
+                ));
+
+                if let Ok(paths) = utils::make_vcpkg_package_search_path(&vcpkg_installed_path) {
+                    let mut vcpkg_libs = VCPKG_LIBS.lock().unwrap();
+                    for t in paths {
+                        vcpkg_libs.push(Box::leak(t.into_boxed_str()))
+                    }
+                }
+            }
+        }
+        progress
+            .report_with_message("Start generating builtin commands", 50)
+            .await;
+        complete::init_builtin_command();
+        progress
+            .report_with_message("Start generating builtin module", 55)
+            .await;
+        complete::init_builtin_module();
+        progress
+            .report_with_message("Start generating builtin variable", 60)
+            .await;
+        complete::init_builtin_variable();
+        progress
+            .report_with_message("Start init system modules", 70)
+            .await;
+        complete::init_system_modules();
+        progress.report_with_message("Scan finished", 100).await;
+        progress.finish().await;
     }
 
     async fn shutdown(&self) -> Result<()> {
@@ -405,7 +440,7 @@ impl LanguageServer for Backend {
                     let Some(ref path) = *self.root_path.lock().await else {
                         continue;
                     };
-                    scansubs::scan_all(path).await;
+                    scansubs::scan_all(path, false).await;
                     continue;
                 }
                 self.client
@@ -502,7 +537,7 @@ impl LanguageServer for Backend {
             }
         };
         if has_root {
-            scansubs::scan_dir(&file_path).await;
+            scansubs::scan_dir(&file_path, false).await;
             complete::update_cache(&file_path, &context).await;
             jump::update_cache(&file_path, &context).await;
         }
